"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const rimraf = require("rimraf");
const spawn = require('child-process-promise').spawn;
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfpowerkit', 'connectedapp_create');
class Create extends command_1.SfdxCommand {
    // Comment this out if your command does not support a hub org username
    // protected static supportsDevhubUsername = true;
    // Set this to true if your command requires a project workspace; 'requiresProject' is false by default
    //protected static requiresProject = true;
    async run() {
        rimraf.sync('temp_sfpowerkit');
        await this.org.refreshAuth();
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        const username = this.org.getUsername();
        const pathToCertificate = this.flags.pathtocertificate.valueOf();
        this.connectedapp_email = this.flags.email;
        this.connectedapp_label = this.flags.name;
        var certificate = fs.readFileSync(pathToCertificate).toString();
        var textblock = certificate.split('\n');
        textblock.splice(0, 1);
        textblock.splice(-2, 1);
        certificate = textblock.join('\n');
        certificate = certificate.replace(/(\r\n|\n|\r)/gm, "");
        this.connectedapp_certificate = certificate;
        this.connectedapp_consumerKey = this.createConsumerKey();
        var connectedApp_metadata = `<?xml version="1.0" encoding="UTF-8"?>
     <ConnectedApp xmlns="http://soap.sforce.com/2006/04/metadata">
         <contactEmail>${this.connectedapp_email}</contactEmail>
         <label>${this.connectedapp_label}</label>
         <oauthConfig>
             <callbackUrl>http://localhost:1717/OauthRedirect</callbackUrl>
             <certificate>${this.connectedapp_certificate}</certificate>
             <consumerKey>${this.connectedapp_consumerKey}</consumerKey>
             <scopes>Api</scopes>
             <scopes>Web</scopes>
             <scopes>RefreshToken</scopes>
         </oauthConfig>
     </ConnectedApp>`;
        var package_xml = `<?xml version="1.0" encoding="UTF-8"?>
     <Package xmlns="http://soap.sforce.com/2006/04/metadata">
         <types>
             <members>*</members>
             <name>ConnectedApp</name>
         </types>
         <version>44.0</version>
     </Package>`;
        let targetmetadatapath = 'temp_sfpowerkit/mdapi/connectedApps/' + this.connectedapp_label + '.connectedApp-meta.xml';
        fs.outputFileSync(targetmetadatapath, connectedApp_metadata);
        let targetpackagepath = 'temp_sfpowerkit/mdapi/package.xml';
        fs.outputFileSync(targetpackagepath, package_xml);
        // Split arguments to use spawn
        const args = [];
        args.push('force:mdapi:deploy');
        // USERNAME
        args.push('--targetusername');
        args.push(`${username}`);
        // MANIFEST
        args.push('--deploydir');
        args.push(`temp_sfpowerkit/mdapi`);
        args.push('--wait');
        args.push(`30`);
        this.ux.log(`Deploy connected app ${this.connectedapp_label}`);
        var startTime = (new Date()).valueOf();
        await spawn('sfdx', args, { stdio: 'inherit' });
        rimraf.sync('temp_sfpowerkit');
        return { 'connectedapp.consumerkey': this.connectedapp_consumerKey };
    }
    createConsumerKey() {
        var text = "";
        var possible = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789.";
        for (var i = 0; i < 32; i++)
            text += possible.charAt(Math.floor(Math.random() * possible.length));
        return text;
    }
}
Create.description = messages.getMessage('commandDescription');
Create.examples = [
    `$ sfdx  sfpowerkit:org:connectedapp:create -u myOrg@example.com -n AzurePipelines -c id_rsa -e azlam.salamm@invalid.com
  Created Connected App AzurePipelines in Target Org
  `
];
Create.flagsConfig = {
    name: command_1.flags.string({ required: true, char: 'n', description: messages.getMessage('nameFlagDescription') }),
    pathtocertificate: command_1.flags.filepath({ required: true, char: 'c', description: messages.getMessage('certificateFlagDescription') }),
    email: command_1.flags.email({ required: true, char: 'e', description: messages.getMessage('emailFlagDescription') })
};
// Comment this out if your command does not require an org username
Create.requiresUsername = true;
exports.default = Create;
//# sourceMappingURL=create.js.map