"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = __importDefault(require("fs-extra"));
const command_1 = require("@salesforce/command");
const rimraf = require("rimraf");
const jsforce_1 = require("jsforce");
const core_1 = require("@salesforce/core");
const xml2js = require("xml2js");
const util = require("util");
// tslint:disable-next-line:ordered-imports
var jsforce = require('jsforce');
var path = require('path');
var unzipper = require('unzipper');
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfpowerkit', 'connectedapp_retrieve');
class Retrieve extends command_1.SfdxCommand {
    async run() {
        rimraf.sync('temp_sfpowerkit');
        if (this.flags.url)
            this.loginUrl = this.flags.url;
        else
            this.loginUrl = 'https://test.salesforce.com';
        if (this.flags.securitytoken)
            this.password = this.flags.password.concat(this.flags.securitytoken);
        else
            this.password = this.flags.password;
        let conn = new jsforce_1.Connection({
            loginUrl: this.loginUrl
        });
        await conn.login(this.flags.username, this.password, function (err, userInfo) {
            if (err) {
                throw new core_1.SfdxError("Unable to connect to the target org");
            }
        });
        let retrieveRequest = {
            apiVersion: '45.0'
        };
        retrieveRequest['singlePackage'] = true;
        retrieveRequest['unpackaged'] = { types: { name: 'ConnectedApp', members: this.flags.name } };
        // if(!this.flags.json)
        // this.ux.logJson(retrieveRequest);
        conn.metadata.pollTimeout = 60;
        let retrievedId;
        await conn.metadata.retrieve(retrieveRequest, function (error, result) {
            if (error) {
                return console.error(error);
            }
            retrievedId = result.id;
        });
        // if(!this.flags.json)
        // console.log(retrievedId);
        let metadata_result;
        let count = 0;
        while (true) {
            count++;
            await conn.metadata.checkRetrieveStatus(retrievedId, function (error, result) {
                if (error) {
                    return console.error(error);
                }
                metadata_result = result;
            });
            if (metadata_result.status == 'Pending') {
                if (!this.flags.json)
                    this.ux.log(`Polling for metadata`);
                await (this.delay(5000));
            }
            else {
                // this.ux.logJson(metadata_result);
                break;
            }
        }
        if (!metadata_result.zipFile)
            throw new core_1.SfdxError("Unable to find the requested connectedapp");
        var zipFileName = "temp_sfpowerkit/unpackaged.zip";
        fs_extra_1.default.mkdirSync('temp_sfpowerkit');
        fs_extra_1.default.writeFileSync(zipFileName, metadata_result.zipFile, { encoding: 'base64' });
        await extract('temp_sfpowerkit');
        let resultFile = `temp_sfpowerkit/connectedApps/${this.flags.name}.connectedApp`;
        // if(!this.flags.json)
        // this.ux.log(`Checking for file ${resultFile}`);
        // this.ux.log(path.resolve(resultFile));
        let retrieved_connectedapp;
        if (fs_extra_1.default.existsSync(path.resolve(resultFile))) {
            const parser = new xml2js.Parser({ explicitArray: false });
            const parseString = util.promisify(parser.parseString);
            retrieved_connectedapp = await parseString(fs_extra_1.default.readFileSync(path.resolve(resultFile)));
            // if(!this.flags.json)
            // this.ux.logJson(retrieved_connectedapp);
            this.ux.log(`Retrieved ConnectedApp Succesfully  with Consumer Key : ${retrieved_connectedapp.ConnectedApp.oauthConfig.consumerKey}`);
        }
        else {
            throw new core_1.SfdxError("Unable to process");
        }
        rimraf.sync('temp_sfpowerkit');
        return { 'connectedapp': retrieved_connectedapp.ConnectedApp };
    }
    async delay(ms) {
        return new Promise(resolve => setTimeout(resolve, ms));
    }
}
Retrieve.description = messages.getMessage('commandDescription');
Retrieve.examples = [
    `$ sfdx  sfpowerkit:org:connectedapp:retrieve -u azlam@sfdc.com -p Xasdax2w2 -n AzurePipelines
  Retrived AzurePipelines Consumer Key : XSD21Sd23123w21321
  `
];
Retrieve.flagsConfig = {
    name: command_1.flags.string({ required: true, char: 'n', description: messages.getMessage('nameFlagDescription') }),
    username: command_1.flags.string({ required: true, char: 'u', description: messages.getMessage('usernameFlagDescription') }),
    password: command_1.flags.string({ required: true, char: 'p', description: messages.getMessage('passwordFlagDescription') }),
    securitytoken: command_1.flags.string({ required: false, char: 's', description: messages.getMessage('securityTokenFlagDescription') }),
    url: command_1.flags.url({ required: false, char: 'r', description: messages.getMessage('securityTokenFlagDescription') }),
};
exports.default = Retrieve;
const extract = (location) => {
    return new Promise((resolve, reject) => {
        fs_extra_1.default.createReadStream(`./${location}/unpackaged.zip`)
            .pipe(unzipper.Extract({ path: `${location}` }))
            .on('close', () => {
            resolve();
        })
            .on('error', error => reject(error));
    });
};
//# sourceMappingURL=retrieve.js.map